@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 use Carp ();
 use Scalar::Util ();
@@ -15,7 +15,7 @@ use overload
     eq => \&is_same_interface
     ;
 
-sub _croak { require Carp; Carp::croak(@_) }
+sub _croak { require Carp; goto &Carp::croak }
 
 sub param_class { 'Sub::Meta::Param' }
 
